@@ -1,6 +1,6 @@
 package TPath::Selector::Self;
 {
-  $TPath::Selector::Self::VERSION = '0.013';
+  $TPath::Selector::Self::VERSION = '0.014';
 }
 
 # ABSTRACT: L<TPath::Selector> that implements C<.>
@@ -13,8 +13,8 @@ with 'TPath::Selector';
 
 # required by TPath::Selector
 sub select {
-    my ( undef, $n ) = @_;
-    $n;
+    my ( undef, $ctx ) = @_;
+    $ctx;
 }
 
 sub to_string { '.' }
@@ -33,7 +33,7 @@ TPath::Selector::Self - L<TPath::Selector> that implements C<.>
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 ROLES
 
