@@ -1,6 +1,6 @@
 package TPath::Test::Or;
 {
-  $TPath::Test::Or::VERSION = '0.013';
+  $TPath::Test::Or::VERSION = '0.014';
 }
 
 # ABSTRACT: implements logical disjunction of tests
@@ -13,9 +13,9 @@ with 'TPath::Test::Compound';
 
 # required by TPath::Test
 sub test {
-    my ( $self, $n, $i, $c ) = @_;
+    my ( $self, $ctx ) = @_;
     for my $t ( @{ $self->tests } ) {
-        return 1 if $t->test( $n, $i, $c );
+        return 1 if $t->test($ctx);
     }
     return 0;
 }
@@ -39,7 +39,7 @@ TPath::Test::Or - implements logical disjunction of tests
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 DESCRIPTION
 
