@@ -7,7 +7,7 @@ use TPath::Grammar qw(parse);
 use Data::Dumper;
 use Perl::Tidy;
 
-my $parse = parse(q{a{}});
+my $parse = parse(q{//b//d//e/previous::*});
 my $code  = Dumper $parse;
 my $ds;
 Perl::Tidy::perltidy( argv => ['-l=0'], source => \$code, destination => \$ds );
